print ("!!!!!!!!!!!!!!!!!! Hello, to  a2connect !!!!!!!!!!!!!!!!!!!!!!")
from a2connect import mod1
from a2connect import mod2
def hello():
    return "!!!!!!!!!!!!!!!!! Hello, world !!!!!!!!!!!!!!!!!!"
x = mod1.shima
y = mod2.evgen
